@@ -15,16 +15,20 @@
 #include <QReadLocker>
 #include <QDebug>
 #include <QDBusInterface>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logDaemon)
 
 using namespace GrandSearch;
 
-class ConfigerGlobal : public Configer {};
+class ConfigerGlobal : public Configer
+{
+};
 Q_GLOBAL_STATIC(ConfigerGlobal, configerGlobal)
 
 ConfigerPrivate::ConfigerPrivate(Configer *parent)
     : q(parent)
 {
-
 }
 
 UserPreferencePointer ConfigerPrivate::defaultSearcher()
@@ -42,13 +46,14 @@ UserPreferencePointer ConfigerPrivate::defaultSearcher()
 
 UserPreferencePointer ConfigerPrivate::fileSearcher()
 {
-    QVariantHash data = {{GRANDSEARCH_GROUP_FOLDER, true},
-                         {GRANDSEARCH_GROUP_FILE, true},
-                         {GRANDSEARCH_GROUP_FILE_VIDEO, true},
-                         {GRANDSEARCH_GROUP_FILE_AUDIO, true},
-                         {GRANDSEARCH_GROUP_FILE_PICTURE, true},
-                         {GRANDSEARCH_GROUP_FILE_DOCUMNET, true},
-                        };
+    QVariantHash data = {
+        { GRANDSEARCH_GROUP_FOLDER, true },
+        { GRANDSEARCH_GROUP_FILE, true },
+        { GRANDSEARCH_GROUP_FILE_VIDEO, true },
+        { GRANDSEARCH_GROUP_FILE_AUDIO, true },
+        { GRANDSEARCH_GROUP_FILE_PICTURE, true },
+        { GRANDSEARCH_GROUP_FILE_DOCUMNET, true },
+    };
 
     return UserPreferencePointer(new UserPreference(data));
 }
@@ -56,8 +61,8 @@ UserPreferencePointer ConfigerPrivate::fileSearcher()
 UserPreferencePointer ConfigerPrivate::tailerData()
 {
     QVariantHash data = {
-        {GRANDSEARCH_TAILER_PARENTDIR, false},
-        {GRANDSEARCH_TAILER_TIMEMODEFIED, true}
+        { GRANDSEARCH_TAILER_PARENTDIR, false },
+        { GRANDSEARCH_TAILER_TIMEMODEFIED, true }
     };
 
     return UserPreferencePointer(new UserPreference(data));
@@ -66,7 +71,7 @@ UserPreferencePointer ConfigerPrivate::tailerData()
 UserPreferencePointer ConfigerPrivate::blacklist()
 {
     QVariantHash data = {
-        {GRANDSEARCH_BLACKLIST_PATH, QStringList("")}
+        { GRANDSEARCH_BLACKLIST_PATH, QStringList("") }
     };
 
     return UserPreferencePointer(new UserPreference(data));
@@ -74,15 +79,14 @@ UserPreferencePointer ConfigerPrivate::blacklist()
 
 UserPreferencePointer ConfigerPrivate::webSearchEngine()
 {
-    QVariantHash data{{GRANDSEARCH_WEB_SEARCHENGINE, ""}};
+    QVariantHash data { { GRANDSEARCH_WEB_SEARCHENGINE, "" } };
 
     return UserPreferencePointer(new UserPreference(data));
 }
 
 UserPreferencePointer ConfigerPrivate::semanticEngine()
 {
-    QVariantHash data{{GRANDSEARCH_CLASS_GENERALFILE_SEMANTIC_ANALYSIS, true}
-                     , {GRANDSEARCH_CLASS_GENERALFILE_SEMANTIC_VECTOR, true}};
+    QVariantHash data { { GRANDSEARCH_CLASS_GENERALFILE_SEMANTIC_ANALYSIS, true }, { GRANDSEARCH_CLASS_GENERALFILE_SEMANTIC_VECTOR, true } };
 
     return UserPreferencePointer(new UserPreference(data));
 }
@@ -95,11 +99,11 @@ bool ConfigerPrivate::updateConfig1(QSettings *set)
     set->beginGroup(GRANDSEARCH_SEARCH_GROUP);
     UserPreferencePointer searcherConfig = m_root->group(GRANDSEARCH_PREF_SEARCHERENABLED);
 
-    //文件搜索相关配置
+    // 文件搜索相关配置
     {
         //初始化文件搜索的子类目
         if (UserPreferencePointer conf = m_root->group(GRANDSEARCH_CLASS_FILE_DEEPIN)) {
-            //若所有的文件类搜索都关闭，则关闭文件搜索项
+            // 若所有的文件类搜索都关闭，则关闭文件搜索项
             bool on = false;
             bool ret = set->value(GRANDSEARCH_GROUP_FOLDER, true).toBool();
             conf->setValue(GRANDSEARCH_GROUP_FOLDER, ret);
@@ -125,32 +129,32 @@ bool ConfigerPrivate::updateConfig1(QSettings *set)
             conf->setValue(GRANDSEARCH_GROUP_FILE_DOCUMNET, ret);
             on |= ret;
 
-            //设置是否启用文件搜索项
+            // 设置是否启用文件搜索项
             searcherConfig->setValue(GRANDSEARCH_CLASS_FILE_DEEPIN, on);
         } else {
-            qWarning() << "no shuch config:" << GRANDSEARCH_CLASS_FILE_DEEPIN;
+            qCWarning(logDaemon) << "Configuration not found:" << GRANDSEARCH_CLASS_FILE_DEEPIN;
         }
     }
 
-    //设置是否启用设置搜索项
+    // 设置是否启用设置搜索项
     {
         bool on = set->value(GRANDSEARCH_GROUP_SETTING, true).toBool();
         searcherConfig->setValue(GRANDSEARCH_CLASS_SETTING_CONTROLCENTER, on);
     }
 
-    //设置是否启用应用搜索项
+    // 设置是否启用应用搜索项
     {
         bool on = set->value(GRANDSEARCH_GROUP_APP, true).toBool();
         searcherConfig->setValue(GRANDSEARCH_CLASS_APP_DESKTOP, on);
     }
 
-    //设置是否启用设置搜索项
+    // 设置是否启用设置搜索项
     {
         bool on = set->value(GRANDSEARCH_GROUP_SETTING, true).toBool();
         searcherConfig->setValue(GRANDSEARCH_CLASS_SETTING_CONTROLCENTER, on);
     }
 
-    //设置是否启用web搜索项
+    // 设置是否启用web搜索项
     {
         bool on = set->value(GRANDSEARCH_GROUP_WEB, true).toBool();
         searcherConfig->setValue(GRANDSEARCH_CLASS_WEB_STATICTEXT, on);
@@ -174,10 +178,10 @@ bool ConfigerPrivate::updateConfig1(QSettings *set)
             ret = set->value(GRANDSEARCH_CLASS_GENERALFILE_SEMANTIC_FULLTEXT, false).toBool();
             conf->setValue(GRANDSEARCH_CLASS_GENERALFILE_SEMANTIC_FULLTEXT, ret);
 
-            //设置是否启用AI搜索项
+            // 设置是否启用AI搜索项
             searcherConfig->setValue(GRANDSEARCH_CLASS_GENERALFILE_SEMANTIC, on);
         } else {
-            qWarning() << "no shuch config:" << GRANDSEARCH_SEMANTIC_GROUP;
+            qCWarning(logDaemon) << "Configuration not found:" << GRANDSEARCH_SEMANTIC_GROUP;
         }
 
         set->endGroup();
@@ -192,7 +196,7 @@ bool ConfigerPrivate::updateConfig1(QSettings *set)
         ret = set->value(GRANDSEARCH_TAILER_TIMEMODEFIED, true).toBool();
         conf->setValue(GRANDSEARCH_TAILER_TIMEMODEFIED, ret);
     } else {
-        qWarning() << "no shuch config:" << GRANDSEARCH_TAILER_GROUP;
+        qCWarning(logDaemon) << "Configuration not found:" << GRANDSEARCH_TAILER_GROUP;
     }
 
     set->endGroup();
@@ -233,7 +237,7 @@ bool ConfigerPrivate::updateConfig1(QSettings *set)
         auto searchEngineCustomAddr = set->value(GRANDSEARCH_WEB_SEARCHENGINE_CUSTOM_ADDR).toString();
         conf->setValue(GRANDSEARCH_WEB_SEARCHENGINE_CUSTOM_ADDR, searchEngineCustomAddr);
     } else {
-        qWarning() << "no shuch config:" << GRANDSEARCH_WEB_SEARCHENGINE;
+        qCWarning(logDaemon) << "Configuration not found:" << GRANDSEARCH_WEB_SEARCHENGINE;
     }
     set->endGroup();
 
@@ -254,8 +258,9 @@ void ConfigerPrivate::resetPath(QString &path) const
     path += "/";
 }
 
-Configer::Configer(QObject *parent) : QObject(parent)
-  , d(new ConfigerPrivate(this))
+Configer::Configer(QObject *parent)
+    : QObject(parent),
+      d(new ConfigerPrivate(this))
 {
     d->m_delayLoad.setSingleShot(true);
     d->m_delayLoad.setInterval(50);
@@ -279,19 +284,19 @@ bool Configer::init()
 
     auto configPath = QStandardPaths::standardLocations(QStandardPaths::ConfigLocation).first();
     configPath = configPath
-                 + "/" + QCoreApplication::organizationName()
-                 + "/" + GRANDSEARCH_DAEMON_NAME
-                 + "/" + GRANDSEARCH_DAEMON_NAME + ".conf";
+            + "/" + QCoreApplication::organizationName()
+            + "/" + GRANDSEARCH_DAEMON_NAME
+            + "/" + GRANDSEARCH_DAEMON_NAME + ".conf";
 
     QFileInfo configFile(configPath);
     if (!configFile.exists()) {
         configFile.absoluteDir().mkpath(".");
 
-        //生成文件
+        // 生成文件
         QFile file(configPath);
         file.open(QFile::NewOnly);
         file.close();
-        qInfo() << "create conf " << configPath;
+        qCInfo(logDaemon) << "Created configuration file:" << configPath;
     }
     d->m_configPath = configFile.absoluteFilePath();
 
@@ -321,7 +326,7 @@ void Configer::initDefault()
 {
     QVariantHash rootData;
 
-    //初始化搜索项是否可用
+    // 初始化搜索项是否可用
     rootData.insert(GRANDSEARCH_PREF_SEARCHERENABLED, QVariant::fromValue(d->defaultSearcher()));
 
     //初始化文件搜索的子类目
@@ -348,25 +353,25 @@ void Configer::initDefault()
 
 void Configer::onFileChanged(const QString &path)
 {
-    qDebug() << "config-file changed" << path;
+    qCDebug(logDaemon) << "Configuration file changed:" << path;
     d->m_delayLoad.start();
 }
 
 void Configer::onLoadConfig()
 {
-    qDebug() << __FUNCTION__;
+    qCDebug(logDaemon) << "Loading configuration";
     if (d->m_configPath.isEmpty())
         return;
 
     QFileInfo configFile(d->m_configPath);
     if (!configFile.exists()) {
-        qWarning() << "config file losted";
+        qCWarning(logDaemon) << "Configuration file not found:" << d->m_configPath;
         return;
     }
 
     QSettings set(d->m_configPath, QSettings::IniFormat);
     if (set.status() != QSettings::NoError) {
-        qWarning() << "config file error" << set.status();
+        qCWarning(logDaemon) << "Configuration file error - Status:" << set.status();
         return;
     }
 
@@ -375,10 +380,10 @@ void Configer::onLoadConfig()
 
     QString ver = set.value("Version_Group/version.config", QString()).toString();
     if (ver.isEmpty()) {
-        qWarning() << "config file error: no version.";
+        qCWarning(logDaemon) << "Configuration file error: Version not found";
         return;
     }
 
-    qInfo() << "config file version is" << ver;
+    qCInfo(logDaemon) << "Configuration file version:" << ver;
     d->updateConfig1(&set);
 }
