@@ -6,15 +6,17 @@
 #include "global/builtinsearch.h"
 #include "filenameworker.h"
 
-#include <dfm-search/dsearch_global.h>
-
 #include <QDBusInterface>
 #include <QDBusReply>
 #include <QDBusConnectionInterface>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logDaemon)
 
 using namespace GrandSearch;
 
-FileNameSearcher::FileNameSearcher(QObject *parent) : Searcher(parent)
+FileNameSearcher::FileNameSearcher(QObject *parent)
+    : Searcher(parent)
 {
 }
 
@@ -25,7 +27,7 @@ QString FileNameSearcher::name() const
 
 bool FileNameSearcher::isActive() const
 {
-    return DFMSEARCH::Global::isFileNameIndexDirectoryAvailable();
+    return true;
 }
 
 bool FileNameSearcher::activate()
@@ -42,7 +44,6 @@ ProxyWorker *FileNameSearcher::createWorker() const
 bool FileNameSearcher::action(const QString &action, const QString &item)
 {
     Q_UNUSED(item)
-    qWarning() << "no such action:" << action << ".";
+    qCWarning(logDaemon) << "Unsupported action requested - Action:" << action;
     return false;
 }
-
