@@ -6,6 +6,9 @@
 #include "generalwidget/detailwidget.h"
 
 #include <QDebug>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logGrandSearch)
 
 using namespace GrandSearch;
 
@@ -19,12 +22,12 @@ PluginProxy::PluginProxy(PreviewWidget *parent)
 void PluginProxy::updateDetailInfo(PreviewPlugin *plugin)
 {
     if (plugin == nullptr || plugin != q->m_preview) {
-        qWarning() << "updateDetailInfo: invaild plugin.";
+        qCWarning(logGrandSearch) << "Invalid plugin provided to updateDetailInfo - Plugin is null or not the current preview plugin";
         return;
     }
 
     if (thread() != qApp->thread()) {
-        qWarning() << __FUNCTION__ << "could not be called in other thread.";
+        qCWarning(logGrandSearch) << "Thread violation - updateDetailInfo must be called from the main thread";
         return;
     }
 
