@@ -26,24 +26,28 @@ public:
     ~Downloader();
 
     void addDownloadTask(const QUrl &url);
+    void cancelDownloads();
     bool isFinished() { return m_finished; }
+    static QString checkCDN(QFile *file);
 
 signals:
     void downloadFinished();
+    void onDownloadProgress(qint64 bytesReceived, qint64 bytesTotal);
 
 private slots:
     void onDownloadFinished(QNetworkReply *reply);
+    void onReadyRead();
 
 private:
-    void saveFile(QNetworkReply *reply, const QString &filename);
-
     QNetworkAccessManager *m_manager;
     QString m_downloadDirectory;
     QList<QNetworkReply*> m_activeDownloads;
+    QHash<QString, QString> urlToFileName;
     bool m_finished;
 
     QMutex mutex;
     QWaitCondition waitCondition;
+    QHash<QNetworkReply*, QFile*> m_openFiles;
 };
 }
 
