@@ -9,6 +9,13 @@
 
 namespace GrandSearch {
 
+enum ModelStatus {
+  None = 0,
+  Install,
+  Uninstall,
+  InstallAndUpdate
+};
+
 class ModelManageButton : public DTK_WIDGET_NAMESPACE::DPushButton
 {
     Q_OBJECT
@@ -20,7 +27,11 @@ public:
 
 protected:
     void paintEvent(QPaintEvent* e) Q_DECL_OVERRIDE;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    void enterEvent(QEnterEvent *event) override;
+#else
     void enterEvent(QEvent *event) override;
+#endif
     void leaveEvent(QEvent *event) override;
     void showEvent(QShowEvent *event) override;
 
