@@ -21,6 +21,8 @@ extern "C" {
 #include <DDesktopEntry>
 #include <DGuiApplicationHelper>
 #include <DDesktopServices>
+#include <DUtil>
+#include <DSysInfo>
 
 #include <QCollator>
 #include <QFileInfo>
@@ -31,8 +33,9 @@ extern "C" {
 #include <QDateTime>
 #include <QIcon>
 #include <QApplication>
-#include <DUtil>
-#include <DSysInfo>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logGrandSearch)
 
 DCORE_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
@@ -50,7 +53,8 @@ static const double TimesWeight = 0.5;
 class DCollator : public QCollator
 {
 public:
-    DCollator() : QCollator()
+    DCollator()
+        : QCollator()
     {
         setCaseSensitivity(Qt::CaseInsensitive);
     }
@@ -59,7 +63,7 @@ public:
 QMap<QString, QString> Utils::m_appIconNameMap;
 QMimeDatabase Utils::m_mimeDb;
 
-bool Utils::sort(MatchedItems &list, Qt::SortOrder order/* = Qt::AscendingOrder*/)
+bool Utils::sort(MatchedItems &list, Qt::SortOrder order /* = Qt::AscendingOrder*/)
 {
     QElapsedTimer time;
     time.start();
@@ -73,7 +77,7 @@ bool Utils::sort(MatchedItems &list, Qt::SortOrder order/* = Qt::AscendingOrder*
     });
 #endif
 
-    qDebug() << QString("sort matchItems done. cost [%1]ms").arg(time.elapsed());
+    qCDebug(logGrandSearch) << "Sorting matched items completed - Time:" << time.elapsed() << "ms";
     return true;
 }
 
@@ -91,8 +95,8 @@ bool Utils::compareByString(QString str1, QString str2, Qt::SortOrder order)
         }
     }
     if (nMidIndex > 0) {
-        str1=str1.mid(nMidIndex);
-        str2=str2.mid(nMidIndex);
+        str1 = str1.mid(nMidIndex);
+        str2 = str2.mid(nMidIndex);
     }
 
     // 其他符号要排在最后
@@ -196,7 +200,7 @@ bool Utils::startWithOtherLang(const QString &text)
             && textScript != QChar::Script_Latin
             && textScript != QChar::Script_Han;
 
-    //qDebug() <<QString("%1 is %2 otherLang").arg(text).arg(bRet ? "" : "not");
+    // qDebug() <<QString("%1 is %2 otherLang").arg(text).arg(bRet ? "" : "not");
     return bRet;
 }
 
@@ -222,7 +226,7 @@ bool Utils::sortByWeight(MatchedItemMap &map, Qt::SortOrder order)
         sortByWeight(list, order);
     }
 
-    qDebug() << QString("sort matchItems by weight done.cost %1ms").arg(time.elapsed());
+    qCDebug(logGrandSearch) << "Sorting matched items by weight completed - Time:" << time.elapsed() << "ms";
     return true;
 }
 
@@ -397,8 +401,8 @@ qint64 Utils::calcDateDiff(const QDateTime &date1, const QDateTime &date2)
 double Utils::calcWeightByDateDiff(const qint64 &diff, const int &type)
 {
     switch (type) {
-    case CreateDateType :
-    case ModifyDateType : {
+    case CreateDateType:
+    case ModifyDateType: {
         switch (diff) {
         case 0:
             return 24;
@@ -413,9 +417,8 @@ double Utils::calcWeightByDateDiff(const qint64 &diff, const int &type)
         default:
             return 0;
         }
-    }
-        break;
-    case ReadDateType : {
+    } break;
+    case ReadDateType: {
         switch (diff) {
         case 0:
             return 9;
@@ -430,8 +433,7 @@ double Utils::calcWeightByDateDiff(const qint64 &diff, const int &type)
         default:
             return 0;
         }
-    }
-        break;
+    } break;
     default:
         return 0;
     }
@@ -487,18 +489,18 @@ void Utils::packageBestMatch(MatchedItemMap &map, int maxQuantity)
     time.start();
 
     static const QMap<QString, bool> supprotedSeracher = {
-        {GRANDSEARCH_CLASS_FILE_DEEPIN, true},
-        {GRANDSEARCH_CLASS_APP_DESKTOP, true},
-        {GRANDSEARCH_CLASS_SETTING_CONTROLCENTER, true},
+        { GRANDSEARCH_CLASS_FILE_DEEPIN, true },
+        { GRANDSEARCH_CLASS_APP_DESKTOP, true },
+        { GRANDSEARCH_CLASS_SETTING_CONTROLCENTER, true },
     };
 
     // 待文件搜索各组去重后删除该黑名单
     static const QMap<QString, bool> blackGroup = {
-        {GRANDSEARCH_GROUP_FILE_VIDEO, false},
-        {GRANDSEARCH_GROUP_FILE_AUDIO, false},
-        {GRANDSEARCH_GROUP_FILE_PICTURE, false},
-        {GRANDSEARCH_GROUP_FILE_DOCUMNET, false},
-        {GRANDSEARCH_GROUP_FOLDER, false}
+        { GRANDSEARCH_GROUP_FILE_VIDEO, false },
+        { GRANDSEARCH_GROUP_FILE_AUDIO, false },
+        { GRANDSEARCH_GROUP_FILE_PICTURE, false },
+        { GRANDSEARCH_GROUP_FILE_DOCUMNET, false },
+        { GRANDSEARCH_GROUP_FOLDER, false }
     };
 
     MatchedItems bestList;
@@ -558,7 +560,7 @@ void Utils::packageBestMatch(MatchedItemMap &map, int maxQuantity)
     for (auto list : tempBestList) {
         // 在原分组中移除最佳匹配项
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-        auto& items = map[list.second];
+        auto &items = map[list.second];
         auto it = std::find(items.begin(), items.end(), list.first);
         if (it != items.end()) {
             items.erase(it);
@@ -571,12 +573,12 @@ void Utils::packageBestMatch(MatchedItemMap &map, int maxQuantity)
 
         // 原分组为空，移除分组
         if (map[list.second].isEmpty()) {
-            qDebug() << "group" << list.second << "is empty, remove it";
+            qCDebug(logGrandSearch) << "Removing empty group - Group:" << list.second;
             map.remove(list.second);
         }
     }
 
-    qDebug() << "find best match count:" << bestList.count() << QString(".cost [%1]ms").arg(time.elapsed());
+    qCDebug(logGrandSearch) << "Best match processing completed - Count:" << bestList.count() << "Time:" << time.elapsed() << "ms";
     if (!bestList.isEmpty()) {
         map.insert(GRANDSEARCH_GROUP_BEST, bestList);
     }
@@ -621,7 +623,7 @@ QString Utils::appIconName(const MatchedItem &item)
     if (item.searcher == GRANDSEARCH_CLASS_APP_DESKTOP) {
         return item.icon;
     } else if (item.searcher == GRANDSEARCH_CLASS_WEB_STATICTEXT) {
-        //默认浏览器图标
+        // 默认浏览器图标
         auto defaultDesktopFile = defaultBrowser();
         if (!defaultDesktopFile.isEmpty()) {
             DDesktopEntry entry(defaultDesktopFile);
@@ -639,7 +641,7 @@ QString Utils::appIconName(const MatchedItem &item)
         if (strAppIconName.isEmpty())
             strAppIconName = "preferences-system";
     } else {
-    // 搜索结果为文件，查询该文件对应默认打开应用图标的名称
+        // 搜索结果为文件，查询该文件对应默认打开应用图标的名称
         QString mimetype = item.type;
         if (mimetype.isEmpty())
             mimetype = getFileMimetype(item.item);
@@ -659,9 +661,9 @@ QString Utils::appIconName(const MatchedItem &item)
 
 bool Utils::isShowAppIcon(const MatchedItem &item)
 {
-    //特殊搜索项
+    // 特殊搜索项
     static QHash<QString, bool> extendSearcher = {
-        {GRANDSEARCH_CLASS_SETTING_CONTROLCENTER, true}
+        { GRANDSEARCH_CLASS_SETTING_CONTROLCENTER, true }
     };
     return isResultFromBuiltSearch(item) || extendSearcher.value(item.searcher, false);
 }
@@ -714,13 +716,13 @@ QString Utils::getFileMimetypeByQt(const QString &path)
 
 QString Utils::getDefaultAppDesktopFileByMimeType(const QString &mimeType)
 {
-    GAppInfo* defaultApp = g_app_info_get_default_for_type(mimeType.toLocal8Bit().constData(), FALSE);
-    if(!defaultApp)
+    GAppInfo *defaultApp = g_app_info_get_default_for_type(mimeType.toLocal8Bit().constData(), FALSE);
+    if (!defaultApp)
         return "";
 
-    const char* desktop_id = g_app_info_get_id(defaultApp);
-    GDesktopAppInfo* desktopAppInfo = g_desktop_app_info_new(desktop_id);
-    if(!desktopAppInfo) {
+    const char *desktop_id = g_app_info_get_id(defaultApp);
+    GDesktopAppInfo *desktopAppInfo = g_desktop_app_info_new(desktop_id);
+    if (!desktopAppInfo) {
         g_object_unref(defaultApp);
         return "";
     }
@@ -760,9 +762,9 @@ bool Utils::openMatchedItem(const MatchedItem &item)
     bool result = false;
     if (item.searcher == GRANDSEARCH_CLASS_APP_DESKTOP) {   // 启动应用
         result = Utils::launchApp(item.item);
-    } else if (item.searcher == GRANDSEARCH_CLASS_WEB_STATICTEXT) { // 跳转浏览器
+    } else if (item.searcher == GRANDSEARCH_CLASS_WEB_STATICTEXT) {   // 跳转浏览器
         result = Utils::openWithBrowser(item.item);
-    } else {    // 打开文件
+    } else {   // 打开文件
         result = openFile(item);
     }
 
@@ -814,8 +816,8 @@ bool Utils::openFile(const MatchedItem &item)
     // 获取对应默认打开应用
     QString defaultDesktopFile = getDefaultAppDesktopFileByMimeType(mimetype);
     if (defaultDesktopFile.isEmpty()) {
-        result = QProcess::startDetached(QString("dde-file-manager"), {QString("-o"), fileUrlString});
-        qDebug() << "open file dialog" << result;
+        result = QProcess::startDetached(QString("dde-file-manager"), { QString("-o"), fileUrlString });
+        qCDebug(logGrandSearch) << "Opening file in file manager - Result:" << result;
     } else {
         QStringList filePaths(fileUrlString);
         result = launchApp(defaultDesktopFile, filePaths);
@@ -824,7 +826,7 @@ bool Utils::openFile(const MatchedItem &item)
     return result;
 }
 
-bool Utils::launchApp(const QString& desktopFile, const QStringList &filePaths)
+bool Utils::launchApp(const QString &desktopFile, const QStringList &filePaths)
 {
     bool ok = launchAppByDBus(desktopFile, filePaths);
     if (!ok) {
@@ -836,55 +838,56 @@ bool Utils::launchApp(const QString& desktopFile, const QStringList &filePaths)
 
 bool Utils::launchAppByDBus(const QString &desktopFile, const QStringList &filePaths)
 {
-    const auto &file = QFileInfo{desktopFile};
+    const auto &file = QFileInfo { desktopFile };
     constexpr auto kDesktopSuffix { u8"desktop" };
 
     if (file.suffix() != kDesktopSuffix) {
-        qDebug() << "invalid desktop file:" << desktopFile << file;
+        qCWarning(logGrandSearch) << "Invalid desktop file format - File:" << desktopFile;
         return false;
     }
 
     auto ver = DSysInfo::majorVersion().toInt();
     if (ver > 20) {
-
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         const QString AppManagerService = "org.desktopspec.ApplicationManager1";
         const QString AppManagerPathPrefix = "/org/desktopspec/ApplicationManager1";
         const QString AppInterface = "org.desktopspec.ApplicationManager1.Application";
 
         const auto &DBusAppId = DUtil::escapeToObjectPath(file.completeBaseName());
         const auto &currentAppPath = QString { AppManagerPathPrefix } + "/" + DBusAppId;
-        qDebug() << "app object path:" << currentAppPath;
+        qCDebug(logGrandSearch) << "Launching application via DBus - Path:" << currentAppPath;
 
         QDBusInterface appManager(AppManagerService,
-                                currentAppPath,
-                                AppInterface,
-                                QDBusConnection::sessionBus());
+                                  currentAppPath,
+                                  AppInterface,
+                                  QDBusConnection::sessionBus());
 
         auto reply = appManager.callWithArgumentList(QDBus::Block, QStringLiteral("Launch"), { QVariant::fromValue(QString {}), QVariant::fromValue(filePaths), QVariant::fromValue(QVariantMap {}) });
 
         return reply.type() == QDBusMessage::ReplyMessage;
-    } else {
-        // V20 Use the SessionManager to launch app
-        const QString SessionManagerService = "com.deepin.SessionManager";
-        const QString StartManagerPath = "/com/deepin/StartManager";
-        const QString StartManagerInterface = "com.deepin.StartManager";
-        QDBusInterface interface(SessionManagerService,
-                                StartManagerPath,
-                                StartManagerInterface,
-                                QDBusConnection::sessionBus());
+#endif
+    }
 
-        QList<QVariant> args;
-        args << desktopFile
-            << QDateTime::currentDateTime().toSecsSinceEpoch()
-            << filePaths;
+    // V20 Use the SessionManager to launch app
+    const QString SessionManagerService = "com.deepin.SessionManager";
+    const QString StartManagerPath = "/com/deepin/StartManager";
+    const QString StartManagerInterface = "com.deepin.StartManager";
+    QDBusInterface interface(SessionManagerService,
+                             StartManagerPath,
+                             StartManagerInterface,
+                             QDBusConnection::sessionBus());
 
-        QDBusPendingCall call = interface.asyncCallWithArgumentList("LaunchApp", args);
+    QList<QVariant> args;
+    args << desktopFile
+         << QDateTime::currentDateTime().toSecsSinceEpoch()
+         << filePaths;
 
-        QDBusReply<void> reply = call.reply();
-        if (!reply.isValid()) {
-                qCritical() << "Launch app by DBus failed:" << reply.error();
-                return false;
-        }
+    QDBusPendingCall call = interface.asyncCallWithArgumentList("LaunchApp", args);
+
+    QDBusReply<void> reply = call.reply();
+    if (!reply.isValid()) {
+        qCCritical(logGrandSearch) << "Failed to launch application via DBus - Error:" << reply.error();
+        return false;
     }
 
     return true;
@@ -898,7 +901,7 @@ bool Utils::launchAppByGio(const QString &desktopFile, const QStringList &filePa
 
     GDesktopAppInfo *appInfo = g_desktop_app_info_new_from_filename(cDesktopPath);
     if (!appInfo) {
-        //qDebug() << "Failed to open desktop file with gio: g_desktop_app_info_new_from_filename returns NULL. Check PATH maybe?";
+        qCWarning(logGrandSearch) << "Failed to create desktop app info - File:" << desktopFile;
         return false;
     }
 
@@ -914,12 +917,12 @@ bool Utils::launchAppByGio(const QString &desktopFile, const QStringList &filePa
     gboolean ok = g_app_info_launch(reinterpret_cast<GAppInfo *>(appInfo), g_files, nullptr, &gError);
 
     if (gError) {
-        qWarning() << "Error when trying to open desktop file with gio:" << gError->message;
+        qCWarning(logGrandSearch) << "Failed to launch application via GIO - Error:" << gError->message;
         g_error_free(gError);
     }
 
     if (!ok) {
-        qWarning() << "Failed to open desktop file with gio: g_app_info_launch returns false";
+        qCWarning(logGrandSearch) << "Application launch via GIO failed - File:" << desktopFile;
     }
     g_object_unref(appInfo);
     g_list_free(g_files);
@@ -940,12 +943,12 @@ bool Utils::openWithBrowser(const QString &words)
     // 获取默认浏览器
     QString defaultDesktopFile = defaultBrowser();
     if (defaultDesktopFile.isEmpty()) {
-        qWarning() << "no browser to open url.";
+        qCWarning(logGrandSearch) << "No default browser found to open URL";
         return false;
     }
-    //默认浏览器
-    qDebug() << "open with" << defaultDesktopFile;
-    return launchApp(defaultDesktopFile, {words});
+    // 默认浏览器
+    qCDebug(logGrandSearch) << "Opening URL in browser - Browser:" << defaultDesktopFile;
+    return launchApp(defaultDesktopFile, { words });
 }
 
 QIcon Utils::defaultIcon(const MatchedItem &item)
@@ -985,12 +988,8 @@ bool Utils::isLevelItem(const MatchedItem &item, int &level)
 
 bool Utils::isLevelGroup(const QString &searchGroupName)
 {
-    static const QStringList containLevelGroup{
-        GRANDSEARCH_GROUP_FILE_VIDEO
-      , GRANDSEARCH_GROUP_FILE_AUDIO
-      , GRANDSEARCH_GROUP_FILE_PICTURE
-      , GRANDSEARCH_GROUP_FILE_DOCUMNET
-      , GRANDSEARCH_GROUP_FILE
+    static const QStringList containLevelGroup {
+        GRANDSEARCH_GROUP_FILE_VIDEO, GRANDSEARCH_GROUP_FILE_AUDIO, GRANDSEARCH_GROUP_FILE_PICTURE, GRANDSEARCH_GROUP_FILE_DOCUMNET, GRANDSEARCH_GROUP_FILE
     };
 
     return containLevelGroup.contains(searchGroupName);
@@ -998,14 +997,8 @@ bool Utils::isLevelGroup(const QString &searchGroupName)
 
 bool Utils::canPreview(const QString &searchGroupName)
 {
-    static const QStringList containPreviewGroup{
-        GRANDSEARCH_GROUP_FOLDER
-      , GRANDSEARCH_GROUP_FILE
-      , GRANDSEARCH_GROUP_FILE_VIDEO
-      , GRANDSEARCH_GROUP_FILE_AUDIO
-      , GRANDSEARCH_GROUP_FILE_PICTURE
-      , GRANDSEARCH_GROUP_FILE_DOCUMNET
-      , GRANDSEARCH_GROUP_FILE_INFERENCE
+    static const QStringList containPreviewGroup {
+        GRANDSEARCH_GROUP_FOLDER, GRANDSEARCH_GROUP_FILE, GRANDSEARCH_GROUP_FILE_VIDEO, GRANDSEARCH_GROUP_FILE_AUDIO, GRANDSEARCH_GROUP_FILE_PICTURE, GRANDSEARCH_GROUP_FILE_DOCUMNET, GRANDSEARCH_GROUP_FILE_INFERENCE
     };
 
     return containPreviewGroup.contains(searchGroupName);
